@@ -25,7 +25,11 @@ if TYPE_CHECKING:
 logger = logging.getLogger("audible.auth")
 
 
-def refresh_access_token(refresh_token: str, domain: str) -> Dict[str, Any]:
+def refresh_access_token(
+        refresh_token: str,
+        domain: str,
+        with_username: bool = False
+) -> Dict[str, Any]:
     """Refreshes an access token.
 
     Args:    
@@ -33,12 +37,16 @@ def refresh_access_token(refresh_token: str, domain: str) -> Dict[str, Any]:
             registration.
         domain: The top level domain of the requested Amazon server
             (e.g. com).
+        with_username: If ``True`` uses `audible` domain instead of `amazon`.
 
     Returns:
         A dict with the new access token and expiration timestamp.
 
     Note:    
         The new access token is valid for 60 minutes.
+
+    .. versionadded:: v0.8
+           The with_username argument
     """
 
     body = {
@@ -49,7 +57,12 @@ def refresh_access_token(refresh_token: str, domain: str) -> Dict[str, Any]:
         "source_token_type": "refresh_token"
     }
 
-    resp = httpx.post(f"https://api.amazon.{domain}/auth/token", data=body)
+    target_domain = "audible" if with_username else "amazon"
+
+    resp = httpx.post(
+        f"https://api.{target_domain}.{domain}/auth/token",
+        data=body
+    )
     resp.raise_for_status()
     resp_dict = resp.json()
 
@@ -61,7 +74,10 @@ def refresh_access_token(refresh_token: str, domain: str) -> Dict[str, Any]:
 
 
 def refresh_website_cookies(
-        refresh_token: str, domain: str, cookies_domain: str
+        refresh_token: str,
+        domain: str,
+        cookies_domain: str,
+        with_username: bool = False
 ) -> Dict[str, str]:
     """Fetches website cookies for a specific domain.
 
@@ -72,13 +88,19 @@ def refresh_website_cookies(
             (e.g. com, de, fr).
         cookies_domain: The top level domain scope for the cookies
             (e.g. com, de, fr).
+        with_username: If ``True`` uses `audible` domain instead of `amazon`.
     
     Returns:
         The requested cookies for the Amazon and Audible website for the given
         `cookies_domain` scope.
+    
+    .. versionadded:: v0.8
+           The with_username argument
     """
 
-    url = f"https://www.amazon.{domain}/ap/exchangetoken"
+    target_domain = "audible" if with_username else "amazon"
+
+    url = f"https://www.{target_domain}.{domain}/ap/exchangetoken/cookies"
 
     body = {
         "app_name": "Audible",
@@ -86,7 +108,7 @@ def refresh_website_cookies(
         "source_token": refresh_token,
         "requested_token_type": "auth_cookies",
         "source_token_type": "refresh_token",
-        "domain": f".amazon.{cookies_domain}"
+        "domain": f".{target_domain}.{cookies_domain}"
     }
 
     resp = httpx.post(url, data=body)
@@ -192,21 +214,17 @@ class Authenticator(httpx.Auth):
         A new class instance have to be instantiate with
         :meth:`Authenticator.from_login` or :meth:`Authenticator.from_file`.
 
-    Attributes:
-        access_token (:obj:`str`, :obj:`None`):
-        activation_bytes (:obj:`str`, :obj:`None`):
-        adp_token (:obj:`str`, :obj:`None`):
-        crypter (:class:`~audible.aescipher.AESCipher`, :obj:`None`):
-        customer_info (:obj:`dict`, :obj:`None`):
-        device_info (:obj:`dict`, :obj:`None`):
-        device_private_key (:obj:`str`, :obj:`None`):
-        encryption (:obj:`str`, :obj:`bool`, :obj:`None`):
-        expires (:obj:`float`, :obj:`None`):
-        filename (:class:`pathlib.Path`, :obj:`None`):
-        locale (:class:`~audible.localization.Locale`, :obj:`None`):
-        refresh_token (:obj:`str`, :obj:`None`):
-        store_authentication_cookie (:obj:`dict`, :obj:`None`):
-        website_cookies (:obj:`dict`, :obj:`None`):
+    .. versionadded:: v0.8
+           The with_username attribute.
+
+    Note:
+        Auth data saved with v0.8 or later 
+        can not be loaded with versions less than v0.8!
+        If an auth file for an pre-Amazon account (with_username=True) was 
+        created with v0.7.1 or v0.7.2 set `auth.with_username` to `True` and 
+        save the data again. After this deregistration, refreshing access 
+        tokens and requesting cookies for another domain will work for 
+        pre-Amazon accounts.
     """
 
     access_token: Optional[str] = None
@@ -223,6 +241,7 @@ class Authenticator(httpx.Auth):
     refresh_token: Optional[str] = None
     store_authentication_cookie: Optional[Dict] = None
     website_cookies: Optional[Dict] = None
+    with_username: Optional[bool] = False
     requires_request_body: bool = True
     _forbid_new_attrs: bool = True
     _apply_test_convert: bool = True
@@ -253,6 +272,43 @@ class Authenticator(httpx.Auth):
         for attr, value in kwargs.items():
             setattr(self, attr, value)
 
+    @classmethod
+    def from_dict(
+            cls,
+            data: Dict,
+            locale: Optional[Union[str, "Locale"]] = None
+    ) -> "Authenticator":
+        """Instantiate an Authenticator from authentication file.
+
+        .. versionadded:: v0.7.1
+
+        Args:
+            data: A dictonary with the authentication data
+            locale: The country code of the Audible marketplace to interact
+                with. If ``None`` the country code from file is used.
+
+
+        Returns:
+            A new Authenticator instance.
+        """
+        auth = cls()
+
+        locale_code = data.pop("locale_code", None)
+        locale = locale or locale_code
+        auth.locale = locale
+
+        if "login_cookies" in data:
+            auth.website_cookies = data.pop("login_cookies")
+
+        auth._update_attrs(**data)
+
+        logger.info(
+            (f"load data from dictionary for locale "
+             f"{auth.locale.country_code}")
+        )
+
+        return auth
+
     @classmethod
     def from_file(
             cls,
@@ -260,7 +316,8 @@ class Authenticator(httpx.Auth):
             password: Optional[str] = None,
             locale: Optional[Union[str, "Locale"]] = None,
             encryption: Optional[Union[bool, str]] = None,
-            **kwargs) -> "Authenticator":
+            **kwargs
+    ) -> "Authenticator":
         """Instantiate an Authenticator from authentication file.
 
         .. versionadded:: v0.5.0
@@ -309,9 +366,8 @@ class Authenticator(httpx.Auth):
 
         # login cookies where renamed to website cookies
         # old names must be adjusted
-        login_cookies = json_data.pop("login_cookies", None)
-        if login_cookies:
-            json_data["website_cookies"] = login_cookies
+        if "login_cookies" in json_data:
+            auth.website_cookies = json_data.pop("login_cookies")
 
         auth._update_attrs(**json_data)
 
@@ -379,9 +435,14 @@ class Authenticator(httpx.Auth):
             approval_callback=approval_callback
         )
         logger.info(f"logged in to Audible as {username}")
-        register_device = register_(**login_device)
+        register_device = register_(
+            with_username=with_username,
+            **login_device
+        )
 
-        auth._update_attrs(**register_device)
+        auth._update_attrs(
+            with_username=with_username,
+            **register_device)
         logger.info("registered Audible device")
 
         return auth
@@ -428,9 +489,15 @@ class Authenticator(httpx.Auth):
         )
         logger.info("logged in to Audible.")
 
-        register_device = register_(**login_device)
+        register_device = register_(
+            with_username=with_username,
+            **login_device
+        )
 
-        auth._update_attrs(**register_device)
+        auth._update_attrs(
+            with_username=with_username,
+            **register_device
+        )
         logger.info("registered Audible device")
 
         return auth
@@ -518,6 +585,30 @@ class Authenticator(httpx.Auth):
 
         return available_modes
 
+    def to_dict(self) -> Dict:
+        """Returns authentication data as dict.
+        
+        .. versionadded:: 0.7.1
+
+        .. versionadded:: v0.8
+           The returned dict now contains the `with_username` attribute
+        """
+        data = {
+            "website_cookies": self.website_cookies,
+            "adp_token": self.adp_token,
+            "access_token": self.access_token,
+            "refresh_token": self.refresh_token,
+            "device_private_key": self.device_private_key,
+            "store_authentication_cookie": self.store_authentication_cookie,
+            "device_info": self.device_info,
+            "customer_info": self.customer_info,
+            "expires": self.expires,
+            "locale_code": self.locale.country_code,
+            "with_username": self.with_username,
+            "activation_bytes": self.activation_bytes
+        }
+        return data
+
     def to_file(
             self,
             filename: Union["pathlib.Path", str] = None,
@@ -529,8 +620,10 @@ class Authenticator(httpx.Auth):
         """Save authentication data to file.
         
         .. versionadded:: 0.5.1
-        
            Save activation bytes to auth file
+
+        .. versionadded:: v0.8
+           The saved file now contains the `with_username` attribute
        """
 
         if not (filename or self.filename):
@@ -546,23 +639,11 @@ class Authenticator(httpx.Auth):
         else:
             encryption = self.encryption or False
 
-        body = {
-            "website_cookies": self.website_cookies,
-            "adp_token": self.adp_token,
-            "access_token": self.access_token,
-            "refresh_token": self.refresh_token,
-            "device_private_key": self.device_private_key,
-            "store_authentication_cookie": self.store_authentication_cookie,
-            "device_info": self.device_info,
-            "customer_info": self.customer_info,
-            "expires": self.expires,
-            "locale_code": self.locale.country_code,
-            "activation_bytes": self.activation_bytes
-        }
-        json_body = json.dumps(body, indent=indent)
+        data = self.to_dict()
+        json_data = json.dumps(data, indent=indent)
 
         if encryption is False:
-            target_file.write_text(json_body)
+            target_file.write_text(json_data)
             crypter = None
         else:
             if password:
@@ -575,7 +656,7 @@ class Authenticator(httpx.Auth):
                 raise ValueError("No password provided")
 
             crypter.to_file(
-                json_body,
+                json_data,
                 filename=target_file,
                 encryption=encryption,
                 indent=indent
@@ -591,12 +672,15 @@ class Authenticator(httpx.Auth):
         logger.info(f"set filename {target_file} as default")
 
     def deregister_device(
-            self, deregister_all: bool = False) -> Dict[str, Any]:
+            self,
+            deregister_all: bool = False
+    ) -> Dict[str, Any]:
         self.refresh_access_token()
         return deregister_(
             access_token=self.access_token,
             deregister_all=deregister_all,
-            domain=self.locale.domain
+            domain=self.locale.domain,
+            with_username=self.with_username
         )
 
     def refresh_access_token(self, force: bool = False) -> None:
@@ -607,7 +691,8 @@ class Authenticator(httpx.Auth):
                 raise NoRefreshToken(message)
             refresh_data = refresh_access_token(
                 refresh_token=self.refresh_token,
-                domain=self.locale.domain
+                domain=self.locale.domain,
+                with_username=self.with_username
             )
 
             self._update_attrs(**refresh_data)
@@ -621,7 +706,11 @@ class Authenticator(httpx.Auth):
         cookies_domain = test_convert("locale", country_code).domain
 
         self.website_cookies = refresh_website_cookies(
-            self.refresh_token, self.locale.domain, cookies_domain)
+            self.refresh_token,
+            self.locale.domain,
+            cookies_domain,
+            self.with_username
+        )
 
     def get_activation_bytes(
             self,
@@ -677,4 +766,3 @@ class Authenticator(httpx.Auth):
     @property
     def access_token_expired(self) -> bool:
         return datetime.fromtimestamp(self.expires) <= datetime.utcnow()
-
