@@ -10,7 +10,9 @@ def register(
         authorization_code: str,
         code_verifier: bytes,
         domain: str,
-        serial: str = None) -> Dict[str, Any]:
+        serial: str = None,
+        with_username: bool = False
+) -> Dict[str, Any]:
     """Registers a dummy Audible device. 
 
     Args:
@@ -18,9 +20,13 @@ def register(
         code_verifier: The verifier code from authorization
         domain: The top level domain of the requested Amazon server (e.g. com).
         serial: The device serial
+        with_username: If ``True`` uses `audible` domain instead of `amazon`.
     
     Returns:
         Additional authentication data needed for access Audible API.
+
+    .. versionadded:: v0.7.1
+           The with_username argument
     """
 
     body = {
@@ -56,7 +62,12 @@ def register(
         "requested_extensions": ["device_info", "customer_info"]
     }
 
-    resp = httpx.post(f"https://api.amazon.{domain}/auth/register", json=body)
+    target_domain = "audible" if with_username else "amazon"
+
+    resp = httpx.post(
+        f"https://api.{target_domain}.{domain}/auth/register",
+        json=body
+    )
 
     resp_json = resp.json()
     if resp.status_code != 200:
@@ -95,7 +106,10 @@ def register(
 
 
 def deregister(
-        access_token: str, domain: str, deregister_all: bool = False
+        access_token: str,
+        domain: str,
+        deregister_all: bool = False,
+        with_username: bool = False
 ) -> Dict[str, Any]:
     """Deregister a previous registered Audible device.
     
@@ -108,16 +122,22 @@ def deregister(
             which you want to deregister.
         domain: The top level domain of the requested Amazon server (e.g. com).
         deregister_all: If ``True``, deregister all Audible devices on Amazon.
+        with_username: If ``True`` uses `audible` domain instead of `amazon`.
 
     Returns:
         The response for the deregister request. Contains errors, if some occurs.
+
+    .. versionadded:: v0.8
+           The with_username argument
     """
 
     body = {"deregister_all_existing_accounts": deregister_all}
     headers = {"Authorization": f"Bearer {access_token}"}
 
+    target_domain = "audible" if with_username else "amazon"
+
     resp = httpx.post(
-        f"https://api.amazon.{domain}/auth/deregister",
+        f"https://api.{target_domain}.{domain}/auth/deregister",
         json=body,
         headers=headers
     )
@@ -127,4 +147,3 @@ def deregister(
         raise Exception(resp_json)
 
     return resp_json
-
